@@ -119,7 +119,7 @@ class ActiveResource(object):
             t = dict(attr.items()).get('type')
             if t and t == 'integer':
                 value = int(value)
-            attrs[attr.tag] = value
+            attrs[attr.tag.replace('-', '_')] = value
         return attrs
     _extract_attrs = classmethod(_extract_attrs)
         
